@@ -95,6 +95,7 @@ class Machine:
                  verbose = True ):
         
         self.hostname = hostname
+        self.distro_ver = distro_ver
         self.distro = self.convert_to_distro(distro, distro_ver)
         if self.distro.package_manager is not None:
             self.repo_utils = RepoUtils(self, self.distro.package_manager)
@@ -163,8 +164,11 @@ class Machine:
                 pass
     
     def interrupt_network(self, time = 120, interface = "eth0"):
-        self.sys("ifdown " + interface + " && sleep " + str(time) + " && ifup eth0",  timeout=3)
-        
+        try:
+            self.sys("ifdown " + interface + " && sleep " + str(time) + " && ifup eth0",  timeout=3)
+        except Exception,e:
+            pass
+
     def sys(self, cmd, verbose=True, timeout=120, listformat=True, code=None):
         '''
         Issues a command against the ssh connection to this instance
@@ -399,22 +403,22 @@ class Machine:
         return ret
     
     def upgrade(self, package=None):
-        self.repo_utils.package_manager.upgrade(package)
+        self.package_manager.upgrade(package)
     
-    def add_repo(self, url):
-        self.repo_utils.package_manager.add_repo(url)
+    def add_repo(self, url, name="test-repo"):
+        self.package_manager.add_repo(url,name)
     
     def install(self, package):
-        self.repo_utils.package_manager.install(package)
+        self.package_manager.install(package)
 
     def update_repos(self):
-        self.repo_utils.package_manager.update_repos()
+        self.package_manager.update_repos()
     
     def get_package_info(self):
-        self.repo_utils.package_manager.get_package_info()
+        self.package_manager.get_package_info()
     
     def get_installed_packages(self):
-        self.repo_utils.package_manager.get_installed_packages()
+        self.package_manager.get_installed_packages()
             
     def get_available(self, path, unit=1):
         """
@@ -467,10 +471,11 @@ class Machine:
     
     def __str__(self):
         s  = "+++++++++++++++++++++++++++++++++++++++++++++++++++++\n"
-        s += "+" + "Hostname:" + self.hostname + "\n"
-        s += "+" + "Distro: " + self.distro +"\n"
-        s += "+" + "Distro Version: " +  self.distro_ver +"\n"
-        s += "+" + "Install Type: " +  self.source +"\n"
+        s += "+" + "Hostname:" + str(self.hostname) + "\n"
+        dname = self.distro.name if self.distro else ""
+        s += "+" + "Distro: " + str(dname) +"\n"
+        s += "+" + "Distro Version: " +  str(self.distro_ver) +"\n"
+        s += "+" + "Install Type: " +  str(self.source) +"\n"
         s += "+" + "Components: " +   str(self.components) +"\n"
         s += "+++++++++++++++++++++++++++++++++++++++++++++++++++++"
         return s
\ No newline at end of file
